pub struct ShadowLodOrigin;Expand description
The entity that Bevy uses to resolve visibility ranges when no specific camera is applicable.
For efficiency, Bevy currently renders point and spot light shadow maps only once per frame, regardless of the number of cameras in use, rather than rendering the shadow maps anew for each camera each frame. Most of the time, this optimization doesn’t change the result relative to a rendering that rendered such shadow maps separately for each camera. However, there’s one exception: visibility ranges. Visibility ranges cause meshes to be visible or invisible depending on the distance from the mesh to the camera. When rendering a shadow map for a point or spot light, Bevy must therefore select an entity to use as the reference point for the purposes of visibility ranges. This entity is called the LOD origin.
Placing this component on an entity makes that entity the origin from which LOD distances are computed for the purposes of shadow mapping of point and spot lights. Typically, you place this component on a camera, but you may place it on another entity if you wish.
The exact algorithm that Bevy uses to determine the LOD origin is as follows. Once the LOD origin is determined, all further steps are skipped.
-
If an entity has this
ShadowLodOrigincomponent, then it’s the LOD origin. If there’s more than one entity with theShadowLodOrigincomponent, one is chosen arbitrarily in a manner that’s stable from frame to frame. -
If a camera renders to a window (that is, the camera’s
RenderTargetisRenderTarget::Window), then that camera is the shadow LOD origin. If there’s more than one such camera that renders to a window, then one is chosen arbitrarily in a manner that’s stable from frame to frame. -
A camera is chosen to be the LOD origin arbitrarily from all cameras in the scene in a manner that’s stable from frame to frame.
This algorithm means that, in most cases, you don’t need to add this
ShadowLodOrigin component explicitly to the scene; usually, Bevy chooses
the right origin automatically. You only need to use this component
explicitly if you have multiple cameras rendering to the window: e.g. in a
split-screen game.